
###
###  Copyright 2000-2008 University of Illinois Board of Trustees
###  All rights reserved.
###
###  auto_direct.pm - psgconf action class for generating /etc/auto_direct
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###

package PSGConf::Action::GenerateFile::auto_direct;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);

###############################################################################
###  generate() method
###############################################################################

sub generate
{
    my ( $self, $fh, $psgconf ) = @_;
    my ( $mounts, $mnt );

    $mounts = $self->{mounts};

    foreach $mnt ( sort keys %$mounts )
    {
        print $fh $mnt . "\t" . '-'
          . $mounts->{$mnt}->{options} . "\t"
          . $mounts->{$mnt}->{location} . "\n";
    }

    return 1;
}

###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::auto_direct - action to generate /etc/auto_direct

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::auto_direct;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::auto_direct->new(
			'name'		=> '/etc/auto_direct',
			'mounts'	=> {
				'/mount/point' => {
					options	=> "soft,rw,intr",
					location => "host:/path"
				},
				...
			},
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::auto_direct> module provides a
B<PSGConf> action class for generating an automounter direct map.

The B<PSGConf::Action::GenerateFile::auto_direct> class is derived from
the B<PSGConf::Action::GenerateFile> class, but it defines/overrides
the following methods:

=over 4

=item generate()

Generates the direct map file based on the value of the I<mounts>
attribute.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::auto_direct> class supports the
following attributes:

=over 4

=item I<mounts>

A reference to a hash that maps absolute paths to a hash containing the
options and location to be mounted at that mount point.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut


