
###
###  Copyright 2000-2008 University of Illinois Board of Trustees
###  All rights reserved.
###
###  PSGConf::DataStore - Base DataStore module for psgconf
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###

###############################################################################
###  Init
###############################################################################

package PSGConf::DataStore;

use strict;

###############################################################################
###  constructor
###############################################################################

sub new
{
    my ( $class, $psgconf, @args ) = @_;
    my ( $self, $arg, $opt, $value );

    $self = {};
    bless( $self, $class );

    foreach $arg (@args)
    {
        ( $opt, $value ) = split( /=/, $arg );
        if ( $opt eq 'config_file' )
        {
            $self->{$opt} = $value;
            next;
        }

        die "PSGConf::DataStore: unknown option '$opt'\n";
    }

    return $self;
}

###############################################################################
###  read config
###############################################################################

sub read_config
{
    my ( $self, $psgconf ) = @_;

    return;
}

###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::DataStore - Base DataStore module for psgconf

=head1 SYNOPSIS

In F<psgconf_modules>:

  DataStore PSGConf::DataStore

=head1 DESCRIPTION

The B<PSGConf::DataStore> module provides a base DataStore 
implementation that reads configuration information from a local config
file (typically F</etc/psg.conf>).  It supports the following methods:

=over 4

=item new()

The constructor.  Its arguments are a reference to the B<PSGConf>
object and an optional list of attribute settings in the form
"attribute=value".  The following attributes are supported:

=over 4

=item I<config_file>

The absolute path to the default config file location.  This value is
overriden by the I<cfgfile> attribute of the B<PSGConf> object.

=back

=item read_config()

This is to be defined in the derived class.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<psgconf-intro>

=cut

