
###
###  Copyright 2000-2008 University of Illinois Board of Trustees
###  All rights reserved.
###
###  PSGConf::Import::group_info - psgconf-import module to parse input
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###

package PSGConf::Import::group_info;

use PSGConf::Action::GenerateFile::etc_group;
use strict;

BEGIN
{
    use Exporter ();
    our ( @ISA, @EXPORT );
    @ISA    = qw(Exporter);
    @EXPORT = qw(&init &sort &parse);
}

sub init
{
    my ($psgconf) = @_;
    my ($self);

    return $self;
}

sub sort
{
    my ($href) = @_;
    my ( $user, @res );

    if ( !exists $href->{name} )
    {
        foreach $user (
            sort PSGConf::Action::GenerateFile::_gid_sort values %{$href} )
        {
            push( @res, $user->{name} );
        }
    } else
    {
        push( @res, ( 'name', 'passwd', 'gid', 'members' ) );
    }
    return \@res;
}

sub parse
{
    my ( $self, $line ) = @_;
    my ( $i, %res );

    ### Remove all comments...
    $line =~ s/#.*$//;

    ### Skip all blank lines...
    return if (m/^$/);

    my ( $name, $pw, $gid, $m ) = split( ':', $line );

    ### If we did not find a name, or a gid, bail...
    return if ( !defined $name || !defined $gid );

    my (@members) = split( /,\s*/, $m );
    $res{$name} = {
        name => $name,
        gid  => $gid
    };

    $res{$name}->{passwd}  = $pw        if ( length $pw );
    $res{$name}->{members} = [@members] if ( scalar @members );

    return ( \$res{$name}, $name );
}

###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Import::group_info - psgconf-import module to parse input

=head1 SYNOPSIS

  use PSGConf::Import::group_info;

=head1 DESCRIPTION

The B<PSGConf::Import::group_info> module provides a class which
defines how psgconf-import will parse the F</etc/group> file
to write out Config::Objective formatted directives to use
in psgconf config files.

=over 4

=item init()

Currently unimplemented.

=item parse()

Reads the F</etc/group> file and returns a C<PSGConf::Data::String>
object for each line.

=back

=head1 SEE ALSO

L<perl>

L<Config::Objective>

=cut

