
###
###  Copyright 2000-2008 University of Illinois Board of Trustees
###  All rights reserved.
###
###  PSGConf::Import::user_info - psgconf-import module to parse input
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###

package PSGConf::Import::user_info;

use PSGConf::Control::Users;
use strict;

BEGIN
{
    use Exporter ();
    our ( @ISA, @EXPORT );
    @ISA    = qw(Exporter);
    @EXPORT = qw(&init &sort &parse);
}

sub init
{
    my ($psgconf) = @_;
    my ($self);

    return $self;
}

sub sort
{
    my ($href) = @_;
    my ( $user, @res );

    if ( !exists $href->{name} )
    {
        foreach $user (
            sort PSGConf::Control::Users::_uid_sort values %{$href} )
        {
            push( @res, $user->{name} );
        }
    } else
    {
        if ( scalar keys %$href > 7 )
        {
            push(
                @res,
                (
                    'name',  'passwd', 'uid',    'gid',
                    'class', 'change', 'expire', 'gecos',
                    'home',  'shell'
                )
            );
        } else
        {
            push( @res,
                ( 'name', 'passwd', 'uid', 'gid', 'gecos', 'home', 'shell' ) );
        }
    }
    return \@res;
}

sub parse
{
    my ( $self, $line ) = @_;
    my ( $i, %res );

    ### Remove all comments...
    $line =~ s/#.*$//;

    ### Skip all blank lines...
    return if (m/^$/);

    my (@a) = split( ':', $line );

    ### If we did not find a name, uid or gid; bail...
    return if ( !defined $a[0] || !defined $a[2] || !defined $a[3] );

    ### If we did not have a shell defined, put the last element
    ### in for the split
    $a[ scalar @a ] = undef
      if ( scalar @a == 6 || scalar @a == 9 );

    $res{ $a[0] } = {
        name  => $a[0],
        uid   => $a[2],
        gid   => $a[3],
        home  => $a[ $#a - 1 ],
        shell => $a[$#a],
    };

    $res{ $a[0] }->{passwd} = $a[1]         if ( length $a[1] );
    $res{ $a[0] }->{gecos}  = $a[ $#a - 2 ] if ( length $a[ $#a - 2 ] );

    ### If we get 10 fields back, then we are probably working on
    ### the master.passwd file from FreeBSD.
    if ( scalar @a > 7 )
    {
        $res{ $a[0] }->{class}  = $a[4] if ( length $a[4] );
        $res{ $a[0] }->{change} = $a[5] if ( length $a[5] );
        $res{ $a[0] }->{expire} = $a[6] if ( length $a[6] );
    }

    return ( \$res{ $a[0] }, $a[0] );
}

###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Import::user_info - psgconf-import module to parse input

=head1 SYNOPSIS

  use PSGConf::Import::user_info;

=head1 DESCRIPTION

The B<PSGConf::Import::user_info> module provides a class which
defines how psgconf-import will parse the F</etc/passwd> file
to write out Config::Objective formatted directives to use
in psgconf config files.

=over 4

=item init()

Currently unimplemented.

=item parse()

Reads the F</etc/passwd> file and returns a C<PSGConf::Data::String>
object for each line.

=back

=head1 SEE ALSO

L<perl>

L<Config::Objective>

=cut

